#
# spec file for package jgraphx
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define src_ver 3_9_2
Name:           jgraphx
Version:        3.9.2
Release:        bp153.1.17
Summary:        Java-based Diagram Component and Editor
License:        BSD-3-Clause
Group:          Development/Libraries/Java
Url:            http://www.jgraph.com/
Source0:        http://downloads.jgraph.com/downloads/jgraphx/archive/jgraphx-%{src_ver}.zip
BuildRequires:  ant
BuildRequires:  java-devel
BuildRequires:  jpackage-utils
BuildRequires:  unzip
Requires:       java
Requires:       jpackage-utils
BuildArch:      noarch

%description
Jgraphx is the a lightweight and feature-rich graph component for Java,
and the successor to jgraph. It provides automatic 2D layout and routing
for diagrams. Object and relations can be displayed in any Swing UI
via provided zoomable component.

%prep
%setup -q -n %{name}

# fix executable permissions
chmod 644 docs/manual/images/mx_man_graph_analysis.jpg

# remove all binary libs
find -type f -name "*.jar" | xargs -t rm

%build
ant -Dant.build.javac.source=1.6 -Dant.build.javac.target=1.6

# Remove copies of source so that we don't confuse
# the debuginfo finder
rm -rf build/src dist/%{name}-%{version}-src

%install

# jars
mkdir -p %{buildroot}%{_javadir}
cp -p lib/jgraphx.jar %{buildroot}%{_javadir}/%{name}-%{version}.jar
pushd  %{buildroot}%{_javadir}
    #create symlink
    ln -s %{name}-%{version}.jar %{name}.jar
popd

%files
%doc license.txt
%{_javadir}/%{name}.jar
%{_javadir}/%{name}-%{version}.jar

%changelog
* Thu Mar  1 2018 pmonrealgonzalez@suse.com
- Updated to version 3.9.2 [bsc#1083413, CVE-2017-18197]
- 28-FEB-2018: 3.9.2
  * Adds supercall to fire execute event in mxMorphing
  * Allows for 0.5px steps in mxGraphHandler.roundLength
  * Fixes possible inconsistency in mxChildChangeCodec
  * Clears selection after editing in mxCellEditor
  * Hides special handles while editing in mxVertexHandler
  * Handles file protocol in mxUrlConverter
  * mxCellEditor handles SVG with absolute position
  * Fixes cloning of edges in mxEdgeHandler
- 27-JAN-2018: 3.9.1
  * Adds resources.html example
  * Adds mxCellEditor.isCancelEditingKeyEvent
  * Adds mxClient.loadResources
  * Adds mxGraph.getLinkForCell hook
- 19-JAN-2018: 3.9.0
  * Add layout.isAncestor where child == parent returns false
  * Removes duplicate WeightedCellSorter
  * Fixes recursion in mxGraph.cellsFolded
  * Adds mxRubberband.fadeOut switch
  * Fixes ignored node values in mxUtils.getPrettyXml
  * Adds editing for edge terminal points
  * Fixes redraw after remove change in mxEdgeHandler
  * Adds loggers, fixes silent fail cases
  * Fixes inline handler in mxEvent.disableContextMenu
  * Fixes mxPanningHandler for mouse up over scrollbar
  * Float loop router ignored for more than 1 point
  * Adds mxVertexHandler.getRotationHandlePosition
- Full changelog in https://www.jgraph.com/mxchangelog.html
* Tue Sep 19 2017 fstrba@suse.com
- Fix build with jdk9: specify java source and target 1.6
* Thu Jan 29 2015 p.drouand@gmail.com
- Update to version 3.1.2.1
  * No changelog available
* Fri Jun 27 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Build on SLE11
* Sat May 17 2014 dmitry_r@opensuse.org
- Remove documentation with problematic license
* Fri May  2 2014 dmitry_r@opensuse.org
- Fix link to source archive
* Sun Mar  9 2014 badshah400@gmail.com
- Update to version 2.5.0.2
  + Lots of changes to list, see
    http://www.jgraph.com/mxchangelog.html for a list.
- Remove conditionals pertaining to EOL openSUSE versions.
* Fri Nov 30 2012 dmitry_r@opensuse.org
- Update to version 1.10.4.0
* Fri Sep  7 2012 dmitry_r@opensuse.org
- Update to version 1.10.3.1
* Sat Jul  7 2012 scorot@free.fr
- fix build for SLE 11
* Fri Sep 24 2010 vincent.lejeune@scilab.org
- update to 1.4.1.0
* Sat Jun 26 2010 kirill.kirillov@gmail.com
- update to 1.4.0.4
* Sun Jun 13 2010 kirill.kirillov@gmail.com
- update to 1.4.0.3
* Thu Mar 11 2010 kirill.kirillov@gmail.com
- simplify spec
* Sat Feb 13 2010 andrea@opensuse.org
- new package
